@@ -1,7 +1,7 @@
 """Module for the Plane class."""
 from __future__ import annotations
 
-from typing import cast
+from typing import Optional
 from typing import Tuple
 
 import numpy as np
@@ -236,12 +236,6 @@ class Plane(_BaseLinePlane, _ToPointsMixin):
 
         d = -self.normal.dot(self.point)
 
-        # Type casting to satisfy mypy.
-        a = cast(np.number, a)
-        b = cast(np.number, b)
-        c = cast(np.number, c)
-        d = cast(np.number, d)
-
         return a, b, c, d
 
     def project_point(self, point: array_like) -> Point:
@@ -490,7 +484,7 @@ class Plane(_BaseLinePlane, _ToPointsMixin):
 
         return line.point + vector_line_scaled
 
-    def intersect_plane(self, other: 'Plane', **kwargs) -> Line:
+    def intersect_plane(self, other: Plane, **kwargs) -> Line:
         """
         Intersect the plane with another.
 
@@ -567,7 +561,7 @@ class Plane(_BaseLinePlane, _ToPointsMixin):
         return Line(point_line, direction_line)
 
     @classmethod
-    def best_fit(cls, points: array_like, tol: float | None = None, **kwargs) -> Plane:
+    def best_fit(cls, points: array_like, tol: Optional[float] = None, **kwargs) -> Plane:
         """
         Return the plane of best fit for a set of 3D points.
 
